import React, { HTMLAttributes, MouseEvent, ReactNode } from 'react';
import { ButtonProps } from '../../components/Button/Button';
import { Override, Size } from '../../type';
interface ActionInfo {
    /** 展示 */
    label?: ReactNode;
    /** 点击回调 */
    onClick?: (e: MouseEvent) => void;
    /** 子菜单，仅 menu 项有效 */
    children?: ActionInfo[];
    /** 提示内容，或自定义 tooltip props */
    tooltip?: ReactNode | any;
    /** 禁用 */
    disabled?: boolean;
    /** 尺寸，仅展示在外可用 */
    size?: Size;
    /** 按钮的 styleType，仅展示在外可用 */
    styleType?: ButtonProps['styleType'];
}
export interface DefinedActionListProps {
    /** 操作列表 */
    actionList: ActionInfo[];
    /** 暴露的操作数量 */
    exposeCount?: number;
    /** 是否自动按照宽度调整展示数量 */
    autoAdjustment?: boolean;
    /** 控件尺寸 */
    size?: Size;
    /** 操作数量等于 exposeCount+1 时是否直接显示按钮而不是显示下拉菜单 */
    smart?: boolean;
    /** 按钮的默认样式类别，参考 Button 的 styleType */
    buttonStyleType?: ButtonProps['styleType'];
    /** 自定义更多按钮内容，也可通过传入 object 来定义 props*/
    dropdownButton?: ReactNode | ButtonProps;
    /** 弹出层的 popover props */
    popoverProps?: any;
}
export declare type ActionListProps = DefinedActionListProps & Override<HTMLAttributes<HTMLDivElement>, DefinedActionListProps>;
declare const _default: React.MemoExoticComponent<({ autoAdjustment: _autoAdjustment, ...rest }: ActionListProps) => JSX.Element>;
export default _default;
